@@ -125,10 +125,14 @@ class AlbumResult(object):
 		new_album = AlbumResult()
 		new_album.imgs = self.imgs
 		new_album.video = self.video
+		if self.imgs or self.video:
+			limit = 4000 - len(self.url) - 10
+		else:
+			limit = 1000 - len(self.url) - 10
 		if self.cap_html_v2:
-			new_album.cap_html_v2 = (self.cap_html_v2.strip() + '\n\n' + self.url).strip()
+			new_album.cap_html_v2 = cutCaptionHtml(self.cap_html_v2, limit) + '\n\n' + self.url
 		elif self.cap or self.imgs or self.video:
-			new_album.cap = (self.cap.strip() + '\n\n' + self.url).strip()
+			new_album.cap = cutCaptionHtml(self.cap, limit) + '\n\n' + self.url
 		return new_album
 
 	def __str__(self):
